/*
Copyright 2010 Johan Maasing

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License.
 */
package nu.zoom.catonine.swing.tail;

import java.awt.Desktop;
import java.awt.event.ActionEvent;
import java.io.File;
import java.io.IOException;

import nu.zoom.catonine.tail.Tailer;
import nu.zoom.gal.error.ErrorReporter;
import nu.zoom.gal.progress.Progress;
import nu.zoom.gal.progress.Progress.TaskID;
import nu.zoom.swing.action.AbstractTypedAction;
import nu.zoom.ui.Resources;
import nu.zoom.ui.Resources.ResourceNotFoundException;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * Edit the current tailing file using the systems default application for
 * editing.
 * 
 * @author "Johan Maasing" &lt;johan@zoom.nu&gt;
 * 
 */
public class EditFileAction extends AbstractTypedAction {
	private static final long serialVersionUID = 1L;
	private final Log log = LogFactory.getLog(getClass());
	private final Tailer tailer;
	private final ErrorReporter errorReporter;
	private final Progress progress;
	private final Resources resources;

	public EditFileAction(final Tailer tailer, final Resources resources, final ErrorReporter errorReporter,
			final Progress progress) {
		this.tailer = tailer;
		this.errorReporter = errorReporter;
		this.progress = progress;
		this.resources = resources;
		try {
			setName(resources.getMessage("nu.zoom.catonine.tail.edit"));
			setToolTip(resources.getMessage("nu.zoom.catonine.tail.edit.tt"));
			setIcon(resources.getIcon("nu.zoom.catonine.tail.edit.icon"));
		} catch (ResourceNotFoundException e) {
		}
		if (Desktop.isDesktopSupported() && Desktop.getDesktop().isSupported(Desktop.Action.EDIT)) {
			log.debug("JVM supports Desktop and Action.EDIT");
			setEnabled(true);
		} else {
			log.debug("JVM does not support Desktop or Action.EDIT, disabling action");
			setEnabled(false);
		}
	}

	/*
	 * (non-Javadoc)
	 * 
	 * @see
	 * java.awt.event.ActionListener#actionPerformed(java.awt.event.ActionEvent)
	 */
	@Override
	public void actionPerformed(ActionEvent e) {
		try {
			File file = tailer.getFile();
			if (file != null) {
				final TaskID taskID = progress.createTask();
				progress.setIndeterminate(taskID);
				Desktop.getDesktop().edit(file);
				try {
					progress.setMessage(taskID,
							resources.format("nu.zoom.catonine.tail.file.edited", file.getAbsolutePath()));
				} catch (ResourceNotFoundException e1) {
					log.error("Unable to find resource nu.zoom.catonine.tail.file.viewed", e1);
				}
				progress.deleteTask(taskID);
			}
		} catch (IOException exc) {
			errorReporter.reportError(exc);
		}
	}

}
